richardview.generic\_serial\_emulator module
============================================

.. automodule:: richardview.generic_serial_emulator
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
